<?php

// -----------------------------------------------------------------#
// Default theme constants
// -----------------------------------------------------------------#
define( 'NECTAR_THEME_DIRECTORY', get_template_directory() );
define( 'NECTAR_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/nectar/' );
define( 'NECTAR_THEME_NAME', 'salient' );


if ( ! function_exists( 'get_nectar_theme_version' ) ) {
	function nectar_get_theme_version() {
		return '10.0.1';
	}
}


// -----------------------------------------------------------------#
// Load text domain
// -----------------------------------------------------------------#
add_action( 'after_setup_theme', 'nectar_lang_setup' );

if ( ! function_exists( 'nectar_lang_setup' ) ) {
	function nectar_lang_setup() {

		load_theme_textdomain( NECTAR_THEME_NAME, get_template_directory() . '/lang' );

	}
}


// -----------------------------------------------------------------#
// Helper to grab Salient theme options
// -----------------------------------------------------------------#
function get_nectar_theme_options() {

	$legacy_options  = get_option( 'salient' );
	$current_options = get_option( 'salient_redux' );

	if ( ! empty( $current_options ) ) {
		return $current_options;
	} elseif ( ! empty( $legacy_options ) ) {
		return $legacy_options;
	} else {
		return $current_options;
	}
}

$nectar_options                    = get_nectar_theme_options();
$nectar_get_template_directory_uri = get_template_directory_uri();


// Default WP video size.
$content_width = 1080;


// -----------------------------------------------------------------#
// Register/Enqueue JS
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/enqueue-scripts.php';


// -----------------------------------------------------------------#
// Register/Enqueue CSS
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/enqueue-styles.php';


// -----------------------------------------------------------------#
// Dynamic Styles
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/dynamic-styles.php';


// Dynamic CSS to be loadded in head.
$nectar_external_dynamic = ( ! empty( $nectar_options['external-dynamic-css'] ) && $nectar_options['external-dynamic-css'] == 1 ) ? 'on' : 'off';
if ( $nectar_external_dynamic != 'on' ) {

	add_action( 'wp_head', 'nectar_colors_css_output' );
	add_action( 'wp_head', 'nectar_custom_css_output' );
	add_action( 'wp_head', 'nectar_fonts_output' );

}

// Dynamic CSS to be enqueued in a file.
else {
	add_action( 'wp_enqueue_scripts', 'nectar_enqueue_dynamic_css' );
}


// -----------------------------------------------------------------#
// Category Custom Meta
// -----------------------------------------------------------------#
require 'nectar/meta/category-meta.php';


// -----------------------------------------------------------------#
// Image sizes
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/media.php';


// -----------------------------------------------------------------#
// Navigation menu locations and custom fields
// -----------------------------------------------------------------#
require_once 'nectar/assets/functions/wp-menu-custom-items/menu-item-custom-fields.php';

require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/nav-menus.php';


// -----------------------------------------------------------------#
// TGM
// -----------------------------------------------------------------#
$nectar_disable_tgm = ( ! empty( $nectar_options['disable_tgm'] ) && $nectar_options['disable_tgm'] == '1' ) ? true : false;

if ( ! $nectar_disable_tgm ) {
	require_once 'nectar/tgm-plugin-activation/class-tgm-plugin-activation.php';
	require_once 'nectar/tgm-plugin-activation/required_plugins.php';
}


// -----------------------------------------------------------------#
// Nectar WPBakery Page Builder
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/wpbakery-init.php';


// -----------------------------------------------------------------#
// Theme Skin
// -----------------------------------------------------------------#
$nectar_theme_skin    = ( ! empty( $nectar_options['theme-skin'] ) ) ? $nectar_options['theme-skin'] : 'original';
$nectar_header_format = ( ! empty( $nectar_options['header_format'] ) ) ? $nectar_options['header_format'] : 'default';

if ( $nectar_header_format == 'centered-menu-bottom-bar' ) {
	$nectar_theme_skin = 'material';
}

add_filter( 'body_class', 'nectar_theme_skin_class' );

function nectar_theme_skin_class( $classes ) {
	global $nectar_theme_skin;
	$classes[] = $nectar_theme_skin;
	return $classes;
}


function nectar_theme_skin_css() {
	global $nectar_theme_skin;
	wp_enqueue_style( 'skin-' . $nectar_theme_skin );
}

add_action( 'wp_enqueue_scripts', 'nectar_theme_skin_css' );


// -----------------------------------------------------------------#
// Search
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/search.php';


// -----------------------------------------------------------------#
// General WP
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/wp-general.php';


// -----------------------------------------------------------------#
// Widget areas and custom widgets
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/widgets.php';


// -----------------------------------------------------------------#
// Header
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/header.php';


// -----------------------------------------------------------------#
// Blog
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/blog.php';


// -----------------------------------------------------------------#
// Portfolio
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/portfolio.php';


// -----------------------------------------------------------------#
// Page
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/page.php';


// -----------------------------------------------------------------#
// Options panel
// -----------------------------------------------------------------#
define( 'CNKT_INSTALLER_PATH', NECTAR_FRAMEWORK_DIRECTORY . 'redux-framework/extensions/wbc_importer/wbc_importer/connekt-plugin-installer/' );

$using_nectar_redux_framework = false;

if ( ! class_exists( 'ReduxFramework' ) && file_exists( dirname( __FILE__ ) . '/nectar/redux-framework/ReduxCore/framework.php' ) ) {
	require_once dirname( __FILE__ ) . '/nectar/redux-framework/ReduxCore/framework.php';
	$using_nectar_redux_framework = true;
}
if ( ! isset( $redux_demo ) && file_exists( dirname( __FILE__ ) . '/nectar/redux-framework/options-config.php' ) ) {
	require_once dirname( __FILE__ ) . '/nectar/redux-framework/options-config.php';
}


require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/redux-salient.php';



// -----------------------------------------------------------------#
// Nectar love
// -----------------------------------------------------------------#
require_once 'nectar/love/nectar-love.php';


// -----------------------------------------------------------------#
// Page meta
// -----------------------------------------------------------------#
require 'nectar/meta/page-meta.php';

$nectar_disable_home_slider   = ( ! empty( $nectar_options['disable_home_slider_pt'] ) && $nectar_options['disable_home_slider_pt'] == '1' ) ? true : false;
$nectar_disable_nectar_slider = ( ! empty( $nectar_options['disable_nectar_slider_pt'] ) && $nectar_options['disable_nectar_slider_pt'] == '1' ) ? true : false;


// -----------------------------------------------------------------#
// Home slider
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/home-slider.php';


if ( $nectar_disable_home_slider != true ) {
	include 'nectar/meta/home-slider-meta.php';
}


// -----------------------------------------------------------------#
// Nectar Slider
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/nectar-slider.php';


if ( $nectar_disable_nectar_slider != true ) {
	include 'nectar/meta/nectar-slider-meta.php';
}


// -----------------------------------------------------------------#
// WPML
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/wpml.php';

// -----------------------------------------------------------------#
// Gutenberg
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/gutenberg.php';


// -----------------------------------------------------------------#
// Shortcodes
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/shortcodes.php';


// -----------------------------------------------------------------#
// Portfolio Meta
// -----------------------------------------------------------------#
require 'nectar/meta/portfolio-meta.php';


// -----------------------------------------------------------------#
// Post meta
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/admin-enqueue.php';


// Post meta core functions.
require 'nectar/meta/meta-config.php';
require 'nectar/meta/post-meta.php';


// -----------------------------------------------------------------#
// Pagination
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/pagination.php';


// -----------------------------------------------------------------#
// Page header
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/page-header.php';


// -----------------------------------------------------------------#
// Woocommerce
// -----------------------------------------------------------------#
global $woocommerce;

// admin notice for left over uneeded template files.
if ( $woocommerce && is_admin() && file_exists( dirname( __FILE__ ) . '/woocommerce/cart/cart.php' ) ) {
	include 'nectar/woo/admin-notices.php';
}

// load product quickview.
$nectar_quick_view_in_use = 'false';
if ( $woocommerce ) {
	$nectar_quick_view = ( ! empty( $nectar_options['product_quick_view'] ) && $nectar_options['product_quick_view'] == '1' ) ? true : false;
	if ( $nectar_quick_view ) {
		$nectar_quick_view_in_use = 'true';
		require_once 'nectar/woo/quick-view.php';
	}
}

require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/woocommerce.php';


// -----------------------------------------------------------------#
// Open Graph
// -----------------------------------------------------------------#
require_once NECTAR_THEME_DIRECTORY . '/nectar/helpers/open-graph.php';



function getsociallinks()
{
	$options = get_nectar_theme_options();
	ob_start();
?>
	<ul class="social">
		<?php
				if ( ! empty( $options['use-twitter-icon'] ) && $options['use-twitter-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['twitter-url'] ); ?>"><i class="fa fa-twitter"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-facebook-icon'] ) && $options['use-facebook-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['facebook-url'] ); ?>"><i class="fa fa-facebook"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-vimeo-icon'] ) && $options['use-vimeo-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['vimeo-url'] ); ?>"> <i class="fa fa-vimeo"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-pinterest-icon'] ) && $options['use-pinterest-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['pinterest-url'] ); ?>"><i class="fa fa-pinterest"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-linkedin-icon'] ) && $options['use-linkedin-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['linkedin-url'] ); ?>"><i class="fa fa-linkedin"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-youtube-icon'] ) && $options['use-youtube-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['youtube-url'] ); ?>"><i class="fa fa-youtube-play"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-tumblr-icon'] ) && $options['use-tumblr-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['tumblr-url'] ); ?>"><i class="fa fa-tumblr"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-dribbble-icon'] ) && $options['use-dribbble-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['dribbble-url'] ); ?>"><i class="fa fa-dribbble"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-rss-icon'] ) && $options['use-rss-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo ( ! empty( $options['rss-url'] ) ) ? esc_url( $options['rss-url'] ) : esc_html( get_bloginfo( 'rss_url' ) ); ?>"><i class="fa fa-rss"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-github-icon'] ) && $options['use-github-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['github-url'] ); ?>"><i class="fa fa-github-alt"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-behance-icon'] ) && $options['use-behance-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['behance-url'] ); ?>"> <i class="fa fa-behance"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-google-plus-icon'] ) && $options['use-google-plus-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['google-plus-url'] ); ?>"><i class="fa fa-google-plus"></i> </a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-instagram-icon'] ) && $options['use-instagram-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['instagram-url'] ); ?>"><i class="fa fa-instagram"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-stackexchange-icon'] ) && $options['use-stackexchange-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['stackexchange-url'] ); ?>"><i class="fa fa-stackexchange"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-soundcloud-icon'] ) && $options['use-soundcloud-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['soundcloud-url'] ); ?>"><i class="fa fa-soundcloud"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-flickr-icon'] ) && $options['use-flickr-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['flickr-url'] ); ?>"><i class="fa fa-flickr"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-spotify-icon'] ) && $options['use-spotify-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['spotify-url'] ); ?>"><i class="icon-salient-spotify"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-vk-icon'] ) && $options['use-vk-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['vk-url'] ); ?>"><i class="fa fa-vk"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-vine-icon'] ) && $options['use-vine-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['vine-url'] ); ?>"><i class="fa-vine"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-houzz-icon'] ) && $options['use-houzz-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['houzz-url'] ); ?>"><i class="fa-houzz"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-yelp-icon'] ) && $options['use-yelp-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['yelp-url'] ); ?>"><i class="fa-yelp"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-snapchat-icon'] ) && $options['use-snapchat-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['snapchat-url'] ); ?>"><i class="fa-snapchat"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-mixcloud-icon'] ) && $options['use-mixcloud-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['mixcloud-url'] ); ?>"><i class="fa-mixcloud"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-bandcamp-icon'] ) && $options['use-bandcamp-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['bandcamp-url'] ); ?>"><i class="fa-bandcamp"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-tripadvisor-icon'] ) && $options['use-tripadvisor-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['tripadvisor-url'] ); ?>"><i class="fa-tripadvisor"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-telegram-icon'] ) && $options['use-telegram-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['telegram-url'] ); ?>"><i class="fa-telegram"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-slack-icon'] ) && $options['use-slack-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['slack-url'] ); ?>"><i class="fa-slack"></i></a></li> <?php } ?>
		<?php
			if ( ! empty( $options['use-medium-icon'] ) && $options['use-medium-icon'] == 1 ) {
		?>
		<li><a target="_blank" href="<?php echo esc_url( $options['medium-url'] ); ?>"><i class="fa-medium"></i></a></li> <?php } ?>
	</ul>
<?php 
	
	return ob_get_clean();
}

add_shortcode('getsocialinks','getsociallinks');